<?php


namespace Hector68\PrestaLiveInform\install;


use Hector68\Liveinform\entities\Config;
use Hector68\Liveinform\entities\Order;
use Hector68\Liveinform\repository\CurlRepository;
use Hector68\PrestaLiveInform\helper\Helper;

class Prestashop15 extends AbstractInstaller
{


    protected $tplDir =  '/../../views/templates/admin/init.tpl';


    public function install()
    {

        include(dirname(__FILE__) . '/sql/install.php');


        return $this->getModule()->registerHook('displayInvoice') && $this->getModule()->registerHook('displayAdminOrder');
    }

    public function uninstall()
    {

        include(dirname(__FILE__) . '/sql/uninstall.php');
        $this->getModule()->unregisterHook('displayInvoice') && $this->getModule()->unregisterHook('displayAdminOrder');
        return true; //
    }


    public function displayInvoice($params)
    {

        return '';
    }


    public function displayAdminOrder($params)
    {
        $order = new \Order($params['id_order']);
        $smarty = \Context::getContext()->smarty;

        if (\Tools::getValue('initLiveInform')) {
            $liveInformSuccess = $this->setUpTrackNumber(['order' => $order]);
            $smarty->assign([
                'liveInformSuccess' => $liveInformSuccess
            ]);
        }

        $sql = new \DbQuery();
        $sql->select('*')
            ->from('liveinform')
            ->where('id_order = ' . pSQL($order->id));

        $needCreate = false;
        if ($row = \Db::getInstance()->getRow($sql)) {

            $widget = $this->getWidget($row['id_liveinform']);

            if(isset($widget['html'])) {
                $smarty->assign([
                    'widget' => $widget['html']
                ]);
            }

        } elseif ($order->shipping_number) {
            $needCreate = true;
        }

        $smarty->assign([
            'needCreate' => $needCreate
        ]);

        return $smarty->fetch(__DIR__.$this->tplDir);
    }


    public function getWidget($id_liveinform)
    {
        $ch = curl_init("http://www.liveinform.ru/api/prestaWidget/");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_TIMEOUT, 30);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, array(
            "api_id" => \Configuration::get('liveinform_api_id'),
            "order_id" => $id_liveinform,
        ));
        $body = curl_exec($ch);
        curl_close($ch);

        $result = explode("\n", $body);

        if (isset($result[0]) && $result[0] == 100) {
          return  json_decode($result[1], true);
        }

        return false;

    }

    public function setUpTrackNumber($params)
    {
        $result = [
            'error' => false,
            'id_order' => null
        ];

        /**
         * @var $order \Order
         */
        $order = $params['order'];
        try {

            $config = new Config(
                \Configuration::get('liveinform_api_id'),
                \Configuration::get('liveinform_type'),
                \Configuration::get('liveinform_test')
            );
            $repository = new CurlRepository($config);

            /** Создаем оьъект заказа */
            $orderLI = new Order(
                Helper::getDataByOrder($order, 'delivery_phone'),
                Helper::getDataByOrder($order, 'shipping_number'),
                Helper::getDataByOrder($order, 'id'),
                Helper::getDataByOrder($order, 'delivery_email'),
                Helper::getDataByOrder($order, 'delivery_name'),
                Helper::getDataByOrder($order, 'delivery_last_name'),
                Helper::getDataByOrder($order, 'total_paid'),
                '',
                Helper::getDataByOrder($order, \Configuration::get('liveinform_additional1')),
                Helper::getDataByOrder($order, \Configuration::get('liveinform_additional2')),
                Helper::getDataByOrder($order, \Configuration::get('liveinform_additional3')),
                'PrestaShop-v'._PS_VERSION_.';module-v'.$this->getModule()->version
            );

            $liveinformId = $repository->save($orderLI);
            $result['id_liveinform'] = $liveinformId->getId();

            if(!$config->isTest()) {
            \Db::getInstance()
                ->insert('liveinform', ['id_liveinform' => $result['id_liveinform'], 'id_order' => $order->id]);
            }


        } catch (\Exception $e) {
            $result['error'] = 'LiveInform: ' . $e->getMessage();

        }

        return $result;

    }


}